# -*- coding:utf-8 -*-

# ProFlow Add-on
# Copyright (C) 2018 Cedric Lepiller aka Pitiwazou
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

import bpy

def get_addon_preferences():
    addon_key = __package__
    return bpy.context.preferences.addons[addon_key].preferences

def set_custom_mesh_from_selection(self, context):
    proflow = context.window_manager.proflow
    if len(context.selected_objects) == 1:
        for o in context.selected_objects:
            if o.type in {'MESH', 'FONT', 'CURVE', 'EMPTY'}:
                proflow.custom_mesh = o

#Recursivly transverse layer_collection for a particular name
def recurLayerCollection(layerColl, collName):
    found = None
    if (layerColl.name == collName):
        return layerColl
    for layer in layerColl.children:
        found = recurLayerCollection(layer, collName)
        if found:
            return found


def proflow_rename_collections(self, context):
    addon_pref = get_addon_preferences()

    # Rename collection
    pf_coll = [coll for coll in context.scene.collection.children if coll.name.startswith("Proflow")]

    if not pf_coll :
        if addon_pref.add_to_collection:
            self.create_collections(context)
    else:
        for coll in pf_coll:
            if len(bpy.data.scenes) >= 2:
                coll.name = "Proflow_" + context.scene.name
            else:
                coll.name = "Proflow"
            self.collection_visibility = coll
            self.coll_is_hidden = False
            if context.view_layer.layer_collection.children[self.collection_visibility.name].exclude:
                self.coll_is_hidden = True
                context.view_layer.layer_collection.children[
                    self.collection_visibility.name].exclude = False

def proflow_create_collections(self, context):
    collection_name = "Proflow"
    myCol = bpy.data.collections.new(collection_name)
    context.scene.collection.children.link(myCol)